@@ -135,6 +135,7 @@ private:
 		float alpha;
 		BorrowedInterpolatedFrameResources resources;
 		RefCountedGLsync fence;  // Set when the interpolated image is read back to the CPU.
+		std::chrono::steady_clock::time_point fence_created;
 		GLuint flow_tex, output_tex, cbcr_tex;  // Released in the receiving thread; not really used for anything else. flow_tex will typically even be from a previous frame.
 		FrameOnDisk id;
 
@@ -142,6 +143,7 @@ private:
 		std::function<void(std::shared_ptr<Frame>)> display_decoded_func;  // Same, except for INTERPOLATED and FADED_INTERPOLATED.
 
 		std::string subtitle;  // Blank for none.
+		std::string exif_data;  // Blank for none.
 
 		// Audio, in stereo interleaved 32-bit PCM. If empty and not of type SILENCE, one frame's worth of silence samples
 		// is synthesized.
