@@ -39,8 +39,9 @@ AudioEncoder::AudioEncoder(const string &codec_name, int bit_rate, const AVOutpu
 	ctx->bit_rate = bit_rate;
 	ctx->sample_rate = OUTPUT_FREQUENCY;
 	ctx->sample_fmt = codec->sample_fmts[0];
-	ctx->channels = 2;
-	ctx->channel_layout = AV_CH_LAYOUT_STEREO;
+	ctx->ch_layout.order = AV_CHANNEL_ORDER_NATIVE;
+	ctx->ch_layout.nb_channels = 2;
+	ctx->ch_layout.u.mask = AV_CH_LAYOUT_STEREO;
 	ctx->time_base = AVRational{1, TIMEBASE};
 	if (oformat->flags & AVFMT_GLOBALHEADER) {
 		ctx->flags |= AV_CODEC_FLAG_GLOBAL_HEADER;
@@ -50,16 +51,17 @@ AudioEncoder::AudioEncoder(const string &codec_name, int bit_rate, const AVOutpu
 		abort();
 	}
 
-	resampler = swr_alloc_set_opts(nullptr,
-	                               /*out_ch_layout=*/AV_CH_LAYOUT_STEREO,
-	                               /*out_sample_fmt=*/ctx->sample_fmt,
-	                               /*out_sample_rate=*/OUTPUT_FREQUENCY,
-	                               /*in_ch_layout=*/AV_CH_LAYOUT_STEREO,
-	                               /*in_sample_fmt=*/AV_SAMPLE_FMT_FLT,
-	                               /*in_sample_rate=*/OUTPUT_FREQUENCY,
-	                               /*log_offset=*/0,
-	                               /*log_ctx=*/nullptr);
-	if (resampler == nullptr) {
+	resampler = nullptr;
+	int ok = swr_alloc_set_opts2(&resampler,
+	                             /*out_ch_layout=*/&ctx->ch_layout,
+	                             /*out_sample_fmt=*/ctx->sample_fmt,
+	                             /*out_sample_rate=*/OUTPUT_FREQUENCY,
+	                             /*in_ch_layout=*/&ctx->ch_layout,
+	                             /*in_sample_fmt=*/AV_SAMPLE_FMT_FLT,
+	                             /*in_sample_rate=*/OUTPUT_FREQUENCY,
+	                             /*log_offset=*/0,
+	                             /*log_ctx=*/nullptr);
+	if (ok != 0) {
 		fprintf(stderr, "Allocating resampler failed.\n");
 		abort();
 	}
@@ -110,8 +112,9 @@ void AudioEncoder::encode_audio_one_frame(const float *audio, size_t num_samples
 {
 	audio_frame->pts = audio_pts;
 	audio_frame->nb_samples = num_samples;
-	audio_frame->channels = 2;
-	audio_frame->channel_layout = AV_CH_LAYOUT_STEREO;
+	audio_frame->ch_layout.order = AV_CHANNEL_ORDER_NATIVE;
+	audio_frame->ch_layout.nb_channels = 2;
+	audio_frame->ch_layout.u.mask = AV_CH_LAYOUT_STEREO;
 	audio_frame->format = ctx->sample_fmt;
 	audio_frame->sample_rate = OUTPUT_FREQUENCY;
 
@@ -132,18 +135,16 @@ void AudioEncoder::encode_audio_one_frame(const float *audio, size_t num_samples
 	}
 
 	for ( ;; ) {  // Termination condition within loop.
-		AVPacket pkt;
-		av_init_packet(&pkt);
-		pkt.data = nullptr;
-		pkt.size = 0;
-		int err = avcodec_receive_packet(ctx, &pkt);
+		AVPacketWithDeleter pkt = av_packet_alloc_unique();
+		pkt->data = nullptr;
+		pkt->size = 0;
+		int err = avcodec_receive_packet(ctx, pkt.get());
 		if (err == 0) {
-			pkt.stream_index = 1;
-			pkt.flags = 0;
+			pkt->stream_index = 1;
+			pkt->flags = 0;
 			for (Mux *mux : muxes) {
-				mux->add_packet(pkt, pkt.pts, pkt.dts);
+				mux->add_packet(*pkt, pkt->pts, pkt->dts);
 			}
-			av_packet_unref(&pkt);
 		} else if (err == AVERROR(EAGAIN)) {
 			break;
 		} else {
@@ -168,18 +169,16 @@ void AudioEncoder::encode_last_audio()
 	if (ctx->codec->capabilities & AV_CODEC_CAP_DELAY) {
 		// Collect any delayed frames.
 		for ( ;; ) {
-			AVPacket pkt;
-			av_init_packet(&pkt);
-			pkt.data = nullptr;
-			pkt.size = 0;
-			int err = avcodec_receive_packet(ctx, &pkt);
+			AVPacketWithDeleter pkt = av_packet_alloc_unique();
+			pkt->data = nullptr;
+			pkt->size = 0;
+			int err = avcodec_receive_packet(ctx, pkt.get());
 			if (err == 0) {
-				pkt.stream_index = 1;
-				pkt.flags = 0;
+				pkt->stream_index = 1;
+				pkt->flags = 0;
 				for (Mux *mux : muxes) {
-					mux->add_packet(pkt, pkt.pts, pkt.dts);
+					mux->add_packet(*pkt, pkt->pts, pkt->dts);
 				}
-				av_packet_unref(&pkt);
 			} else if (err == AVERROR_EOF) {
 				break;
 			} else {
