@@ -132,6 +132,14 @@ void AV1Encoder::add_frame(int64_t pts, int64_t duration, YCbCrLumaCoefficients
 void AV1Encoder::init_av1()
 {
 	EbSvtAv1EncConfiguration config;
+
+	// svt_av1_enc_init_handle() is defined to fill config with the defaults;
+	// yet, seemingly, not everything is written, and some of it can cause
+	// Valgrind warnings and/or crashes. It should never hurt to put it
+	// into a known state beforehand, and it seems to fix the crashes,
+	// so we do that.
+	memset(&config, 0, sizeof(config));
+
 	EbErrorType ret = svt_av1_enc_init_handle(&encoder, nullptr, &config);
 	if (ret != EB_ErrorNone) {
 		fprintf(stderr, "Error initializing SVT-AV1 handle (error %08x)\n", ret);
@@ -147,6 +155,7 @@ void AV1Encoder::init_av1()
 	config.frame_rate_numerator = global_flags.av1_fps_num;
 	config.frame_rate_denominator = global_flags.av1_fps_den;
 	config.encoder_bit_depth = global_flags.bit_depth;
+	config.rate_control_mode = 1;  // VBR.
 	config.target_bit_rate = global_flags.av1_bitrate * 1000;
 
 	// NOTE: These should be in sync with the ones in quicksync_encoder.cpp (sps_rbsp()).
@@ -158,9 +167,7 @@ void AV1Encoder::init_av1()
 		config.matrix_coefficients = EB_CICP_MC_BT_601;
 	}
 	config.color_range = EB_CR_STUDIO_RANGE;
-#if SVT_AV1_CHECK_VERSION(1, 0, 0)
 	config.chroma_sample_position = EB_CSP_VERTICAL;
-#endif
 
 	const vector<string> &extra_param = global_flags.av1_extra_param;
 	for (const string &str : extra_param) {
@@ -302,7 +309,7 @@ void AV1Encoder::encode_frame(AV1Encoder::QueuedFrame qf)
 		hdr.n_alloc_len   = (global_flags.width * global_flags.height * 3 / 2) * bytes_per_pixel;
 		hdr.n_filled_len  = hdr.n_alloc_len;
 		hdr.n_tick_count  = 0;
-		hdr.p_app_private = reinterpret_cast<void *>(intptr_t(qf.duration));
+		hdr.p_app_private = nullptr;
 		hdr.pic_type      = EB_AV1_INVALID_PICTURE;  // Actually means auto, according to FFmpeg.
 		hdr.metadata      = nullptr;
 		hdr.flags         = 0;
