@@ -38,6 +38,7 @@
 
 extern "C" {
 #include <libswresample/swresample.h>
+#include <libavutil/channel_layout.h>
 #include <libavutil/pixfmt.h>
 #include <libavutil/rational.h>
 #include <libavutil/samplefmt.h>
@@ -288,6 +289,10 @@ private:
 	std::atomic<bool> should_interrupt{false};
 	bool last_frame_was_connected = true;
 
+	// TODO: Replace with std::optional if we go C++17.
+	bool frame_timeout_valid = false;  // If true, will time out any reads after ten seconds.
+	std::chrono::steady_clock::time_point frame_timeout_started;  // Only relevant if frame_timeout_valid == true.
+
 	bool has_dequeue_callbacks = false;
 	std::function<void()> dequeue_init_callback = nullptr;
 	std::function<void()> dequeue_cleanup_callback = nullptr;
@@ -326,7 +331,7 @@ private:
 	// Audio resampler.
 	SwrContext *resampler = nullptr;
 	AVSampleFormat last_src_format, last_dst_format;
-	int64_t last_channel_layout;
+	AVChannelLayout last_channel_layout;
 	int last_sample_rate;
 
 	// Subtitles (no decoding done, really).
