@@ -83,6 +83,11 @@ struct Flags {
 	bool use_zerocopy = false;  // Not user-settable.
 	bool fullscreen = false;
 	std::map<unsigned, unsigned> card_to_mjpeg_stream_export;  // If a card is not in the map, it is not exported.
+	std::string srt_destination_host;
+	std::string srt_destination_port;
+	std::string srt_streamid;
+	std::string srt_passphrase;
+	int srt_output_latency_ms = DEFAULT_SRT_OUTPUT_LATENCY_MS;
 };
 extern Flags global_flags;
 
