@@ -277,6 +277,26 @@ MainWindow::MainWindow()
 		global_flags.enable_quick_cut_keys = ui->quick_cut_enable_action->isChecked();
 	});
 
+#if HAVE_SRT
+	if (global_flags.srt_port >= 0) {
+		char title[256];
+		snprintf(title, sizeof(title), "Accept new SRT connections on port %d", global_flags.srt_port);
+		ui->srt_enable_action->setChecked(true);
+		ui->srt_enable_action->setText(title);
+		connect(ui->srt_enable_action, &QAction::changed, [this](){
+			global_flags.enable_srt = ui->srt_enable_action->isChecked();
+		});
+	} else {
+		ui->srt_enable_action->setChecked(false);
+		ui->srt_enable_action->setEnabled(false);
+		ui->srt_enable_action->setText("Accept new SRT connections");
+	}
+#else
+	ui->srt_enable_action->setChecked(false);
+	ui->srt_enable_action->setEnabled(false);
+	ui->srt_enable_action->setText("Accept new SRT connections");
+#endif
+
 	last_audio_level_callback = steady_clock::now() - seconds(1);
 
 	if (!global_flags.midi_mapping_filename.empty()) {
@@ -1182,6 +1202,19 @@ void MainWindow::set_treble(unsigned bus_idx, float value)
 	set_relative_value_if_exists(bus_idx, &Ui::AudioExpandedView::treble_knob, value);
 }
 
+void MainWindow::set_eq_absolute(unsigned bus_idx, EQBand eq_band, float value_db)
+{
+	if (eq_band == EQ_BAND_TREBLE) {
+		set_db_value_if_exists(bus_idx, &Ui::AudioExpandedView::treble_knob, value_db);
+	} else if (eq_band == EQ_BAND_MID) {
+		set_db_value_if_exists(bus_idx, &Ui::AudioExpandedView::mid_knob, value_db);
+	} else if (eq_band == EQ_BAND_BASS) {
+		set_db_value_if_exists(bus_idx, &Ui::AudioExpandedView::bass_knob, value_db);
+	} else {
+		assert(false);
+	}
+}
+
 void MainWindow::set_mid(unsigned bus_idx, float value)
 {
 	set_relative_value_if_exists(bus_idx, &Ui::AudioExpandedView::mid_knob, value);
@@ -1207,6 +1240,15 @@ void MainWindow::set_fader(unsigned bus_idx, float value)
 	set_relative_value_if_exists(bus_idx, &Ui::AudioExpandedView::fader, value);
 }
 
+void MainWindow::set_fader_absolute(unsigned bus_idx, float value_db)
+{
+	if (global_audio_mixer != nullptr &&
+	    global_audio_mixer->get_mapping_mode() == AudioMixer::MappingMode::MULTICHANNEL &&
+	    bus_idx < audio_expanded_views.size()) {
+		audio_expanded_views[bus_idx]->fader->setDbValue(value_db);
+	}
+}
+
 void MainWindow::toggle_mute(unsigned bus_idx)
 {
 	click_button_if_exists(bus_idx, &Ui::AudioExpandedView::mute_button);
@@ -1424,6 +1466,18 @@ void MainWindow::set_relative_value_if_exists(unsigned bus_idx, T *(Ui_AudioExpa
 	}
 }
 
+void MainWindow::set_db_value_if_exists(unsigned bus_idx, QDial *(Ui_AudioExpandedView::*control), float value_db)
+{
+	post_to_main_thread([this, bus_idx, control, value_db]{
+		if (global_audio_mixer != nullptr &&
+		    global_audio_mixer->get_mapping_mode() == AudioMixer::MappingMode::MULTICHANNEL &&
+		    bus_idx < audio_expanded_views.size()) {
+			int value = lrintf(value_db * 10.0f);
+			(audio_expanded_views[bus_idx]->*control)->setValue(value);
+		}
+	});
+}
+
 template<class T>
 void MainWindow::click_button_if_exists(unsigned bus_idx, T *(Ui_AudioExpandedView::*control))
 {
