@@ -47,6 +47,14 @@ public:
 	virtual void toggle_limiter() = 0;
 	virtual void toggle_auto_makeup_gain() = 0;
 
+	// Non-audio events.
+	virtual void switch_video_channel(int channel_number) = 0;
+	virtual void apply_transition(int transition_number) = 0;
+	virtual void prev_audio_view() = 0;
+	virtual void next_audio_view() = 0;
+	virtual void begin_new_segment() = 0;
+	virtual void exit() = 0;
+
 	// Signals to highlight controls to mark them to the user
 	// as MIDI-controllable (or not).
 	virtual void clear_all_highlights() = 0;
