@@ -37,6 +37,7 @@
 #include "queue_length_policy.h"
 #include "ref_counted_frame.h"
 #include "shared/ref_counted_gl_sync.h"
+#include "srt_metrics.h"
 #include "theme.h"
 #include "shared/timebase.h"
 #include "video_encoder.h"
@@ -521,52 +522,9 @@ private:
 		std::atomic<int64_t> metric_input_frame_rate_den{-1};
 		std::atomic<int64_t> metric_input_sample_rate_hz{-1};
 
-		// SRT metrics.
-		std::atomic<double> metric_srt_uptime_seconds{0.0 / 0.0};
-		std::atomic<double> metric_srt_send_duration_seconds{0.0 / 0.0};
-		std::atomic<int64_t> metric_srt_sent_bytes{-1};
-		std::atomic<int64_t> metric_srt_received_bytes{-1};
-		std::atomic<int64_t> metric_srt_sent_packets_normal{-1};
-		std::atomic<int64_t> metric_srt_received_packets_normal{-1};
-		std::atomic<int64_t> metric_srt_sent_packets_lost{-1};
-		std::atomic<int64_t> metric_srt_received_packets_lost{-1};
-		std::atomic<int64_t> metric_srt_sent_packets_retransmitted{-1};
-		std::atomic<int64_t> metric_srt_sent_bytes_retransmitted{-1};
-		std::atomic<int64_t> metric_srt_sent_packets_ack{-1};
-		std::atomic<int64_t> metric_srt_received_packets_ack{-1};
-		std::atomic<int64_t> metric_srt_sent_packets_nak{-1};
-		std::atomic<int64_t> metric_srt_received_packets_nak{-1};
-		std::atomic<int64_t> metric_srt_sent_packets_dropped{-1};
-		std::atomic<int64_t> metric_srt_received_packets_dropped{-1};
-		std::atomic<int64_t> metric_srt_sent_bytes_dropped{-1};
-		std::atomic<int64_t> metric_srt_received_bytes_dropped{-1};
-		std::atomic<int64_t> metric_srt_received_packets_undecryptable{-1};
-		std::atomic<int64_t> metric_srt_received_bytes_undecryptable{-1};
-
-		std::atomic<int64_t> metric_srt_filter_received_extra_packets{-1};
-		std::atomic<int64_t> metric_srt_filter_received_rebuilt_packets{-1};
-		std::atomic<int64_t> metric_srt_filter_received_lost_packets{-1};
-
-		std::atomic<double> metric_srt_packet_sending_period_seconds{0.0 / 0.0};
-		std::atomic<int64_t> metric_srt_flow_window_packets{-1};
-		std::atomic<int64_t> metric_srt_congestion_window_packets{-1};
-		std::atomic<int64_t> metric_srt_flight_size_packets{-1};
-		std::atomic<double> metric_srt_rtt_seconds{0.0 / 0.0};
-		std::atomic<double> metric_srt_estimated_bandwidth_bits_per_second{0.0 / 0.0};
-		std::atomic<double> metric_srt_bandwidth_ceiling_bits_per_second{0.0 / 0.0};
-		std::atomic<int64_t> metric_srt_send_buffer_available_bytes{-1};
-		std::atomic<int64_t> metric_srt_receive_buffer_available_bytes{-1};
-		std::atomic<int64_t> metric_srt_mss_bytes{-1};
-		std::atomic<int64_t> metric_srt_sender_unacked_packets{-1};
-		std::atomic<int64_t> metric_srt_sender_unacked_bytes{-1};
-		std::atomic<double> metric_srt_sender_unacked_timespan_seconds{0.0 / 0.0};
-		std::atomic<double> metric_srt_sender_delivery_delay_seconds{0.0 / 0.0};
-		std::atomic<int64_t> metric_srt_receiver_unacked_packets{-1};
-		std::atomic<int64_t> metric_srt_receiver_unacked_bytes{-1};
-		std::atomic<double> metric_srt_receiver_unacked_timespan_seconds{0.0 / 0.0};
-		std::atomic<double> metric_srt_receiver_delivery_delay_seconds{0.0 / 0.0};
-		std::atomic<int64_t> metric_srt_filter_sent_packets{-1};
-
+#ifdef HAVE_SRT
+		SRTMetrics srt_metrics;
+#endif
 	};
 	JitterHistory output_jitter_history;
 	CaptureCard cards[MAX_VIDEO_CARDS];  // Protected by <card_mutex>.
@@ -583,10 +541,6 @@ private:
 	};
 	OutputFrameInfo get_one_frame_from_each_card(unsigned master_card_index, bool master_card_is_output, CaptureCard::NewFrame new_frames[MAX_VIDEO_CARDS], bool has_new_frame[MAX_VIDEO_CARDS], std::vector<int32_t> raw_audio[MAX_VIDEO_CARDS]);
 
-#ifdef HAVE_SRT
-	void update_srt_stats(int srt_sock, Mixer::CaptureCard *card);
-#endif
-
 	std::string description_for_card(unsigned card_index);
 	static bool is_srt_card(const CaptureCard *card);
 
