@@ -191,8 +191,9 @@ void add_audio_stream(AVFormatContext *avctx)
 	stream->time_base = AVRational{ 1, OUTPUT_FREQUENCY };
 	stream->codecpar->codec_type = AVMEDIA_TYPE_AUDIO;
 	stream->codecpar->codec_id = AV_CODEC_ID_PCM_S32LE;
-	stream->codecpar->channel_layout = AV_CH_LAYOUT_STEREO;
-	stream->codecpar->channels = 2;
+	stream->codecpar->ch_layout.order = AV_CHANNEL_ORDER_NATIVE;
+	stream->codecpar->ch_layout.nb_channels = 2;
+	stream->codecpar->ch_layout.u.mask = AV_CH_LAYOUT_STEREO;
 	stream->codecpar->sample_rate = OUTPUT_FREQUENCY;
 }
 
