@@ -56,6 +56,10 @@ public:
 	{
 		http_mux = mux;
 	}
+	void set_srt_mux(Mux *mux)
+	{
+		srt_mux = mux;
+	}
 
 	// So we never get negative dts.
 	int64_t global_delay() const {
@@ -175,6 +179,7 @@ private:
 	std::unique_ptr<V4LOutput> v4l_output;  // nullptr if not using V4L2 output.
 
 	Mux* http_mux = nullptr;  // To the HTTP server.
+	Mux* srt_mux = nullptr;  // To the remote SRT endpoint, if any.
 	std::unique_ptr<Mux> file_mux;  // To local disk.
 
 	// Encoder parameters
