@@ -422,7 +422,7 @@ Effect *Scene::instantiate_effects(const Block *block, size_t chain_idx, Scene::
 			pixel_format = bmusb::PixelFormat_8BitBGRA;
 		} else if (chosen_type == LIVE_INPUT_YCBCR_PLANAR) {
 			pixel_format = bmusb::PixelFormat_8BitYCbCrPlanar;
-		} else if (global_flags.ten_bit_input) {
+		} else if (global_flags.bit_depth > 8) {
 			pixel_format = bmusb::PixelFormat_10BitYCbCr;
 		} else {
 			pixel_format = bmusb::PixelFormat_8BitYCbCr;
@@ -475,7 +475,7 @@ int Scene::finalize(lua_State* L)
 		}
 	}
 	const size_t total_cardinality = real_cardinality * (only_one_mode ? 1 : 2);
-	if (total_cardinality > 200) {
+	if (total_cardinality > 400) {
 		print_warning(L, "The given Scene will instantiate %zu different versions. This will take a lot of time and RAM to compile; see if you could limit some options by e.g. locking the input type in some cases (by giving a fixed input to add_input()).\n",
 			total_cardinality);
 	}
